@@ -423,67 +423,3 @@ setAs('grf', 'RasterLayer',
 	}
 )
 
-
-setAs('RasterLayer', 'big.matrix',
-	function(from) {
-
-		if (!require(bigmemory)) { 
-			stop('You need to install the bigmemory package') 
-		}
-		stopifnot(hasValues(from))
-
-		if (fromDisk(from) & .driver(from) == 'big.matrix') {
-			return(attr(from, 'big.matrix'))
-			# or copy the big.matrix to a new file and return that?
-			# to avoid changing data that then no longer matches metadata file
-		}
-		
-		b <- big.matrix(nrow(from), ncol(from))
-
-		if (canProcessInMemory(from)) {
-			b[]  <- as.matrix(from)
-		} else {
-			tr <- blockSize(from)
-			pb <- pbCreate(tr$n)			
-			for (i in 1:tr$n) {
-				b[tr$row[i]:(tr$row[i]+tr$nrows[i]-1), ] <- getValues(from, row=tr$row[i], nrows=tr$nrows[i], format='matrix')
-				pbStep(pb) 
-			}
-			pbClose(pb)
-		}	
-		b
-	}
-)
-
-
-setAs('RasterStackBrick', 'big.matrix',
-	function(from) {
-
-	if (!require(bigmemory)) { 
-		stop('You need to install the bigmemory package') 
-	}
-	stopifnot(hasValues(from))
-
-	names(b) <- colnames(from)
-
-	b <- big.matrix(ncell(from), nlayers(from) )
-	
-	op <- options('bigmemory.allow.dimnames')
-	options(bigmemory.allow.dimnames=TRUE)
-	colnames(b) <- names(from)
-	options(bigmemory.allow.dimnames=op)
-
-	if (canProcessInMemory(from)) {
-		b[]  <- as.matrix(from)
-	} else {
-		tr <- blockSize(from)
-		pb <- pbCreate(tr$n)
-		for (i in 1:tr$n) {
-			b[tr$row[i]:(tr$row[i]+tr$nrows[i]-1), ] <- getValues(from, row=tr$row[i], nrows=tr$nrows[i], format='matrix')
-			pbStep(pb) 
-		}
-		pbClose(pb)
-	}	
-	b
-} )
-
