@@ -4,7 +4,7 @@
 # Licence GPL v3
 
 
-.rasterObjectFromFile <- function(x, band=1, objecttype='RasterLayer', native=FALSE, silent=TRUE, offset=NULL, ncdf=FALSE, GMT=FALSE, ...) {
+.rasterObjectFromFile <- function(x, band=1, objecttype='RasterLayer', native=FALSE, silent=TRUE, offset=NULL, ncdf=FALSE, ...) {
 	x <- trim(x)
 	if (x=='' | x=='.') { # etc? 
 		stop('provide a valid filename')
@@ -43,9 +43,9 @@
 		}
 	}
 
-	if (isTRUE(GMT)) {
-		return(.rasterObjectFromCDF_GMT(x))
-	}
+	#if (isTRUE(GMT)) {
+	#	return(.rasterObjectFromCDF_GMT(x))
+	#}
 	if (( fileext %in% c(".NC", ".NCF", ".NC4", ".CDF", ".NCDF", ".NETCDF")) | (isTRUE(ncdf))) {
 		return ( .rasterObjectFromCDF(x, type=objecttype, band=band, ...) )
 		# return ( .rasterFromCDF(x, objecttype, ...) )
@@ -73,7 +73,7 @@
 	}
 	if (native) {
 		if ( fileext == ".ASC" ) {
-			return ( .rasterFromASCIIFile(x, ...) )
+			return ( .rasterFromASCIIFile(x) )
 		}
 		if ( fileext %in% c(".BIL", ".BIP", ".BSQ")) {
 			return ( .rasterFromGenericFile(x, type=objecttype, ...) )
